@@ -6,6 +6,8 @@ Specify the options when running the data profiler.
 import warnings
 import abc
 import copy
+from ..labelers.data_labelers import DataLabeler
+from ..labelers.base_data_labeler import BaseDataLabeler
 
 
 class BaseOption(object):
@@ -314,6 +316,17 @@ class IntOptions(NumericalOptions):
         """
         NumericalOptions.__init__(self)
 
+    def _validate_helper(self, variable_path='IntOptions'):
+        """
+        Validates the options do not conflict and cause errors.
+
+        :param variable_path: current path to variable set.
+        :type variable_path: str
+        :return: list of errors (if raise_error is false)
+        :rtype: list(str)
+        """
+        return super()._validate_helper(variable_path) 
+
 
 class FloatOptions(NumericalOptions):
     def __init__(self):
@@ -355,7 +368,7 @@ class FloatOptions(NumericalOptions):
         if not isinstance(self.precision, BooleanOption):
             errors.append("{}.precision must be a BooleanOption."
                           .format(variable_path))
-        errors += self.precision._validate_helper(variable_path)
+        errors += self.precision._validate_helper(variable_path + '.precision')
         return errors
 
 
@@ -399,7 +412,7 @@ class TextOptions(NumericalOptions):
         if not isinstance(self.vocab, BooleanOption):
             errors.append("{}.vocab must be a BooleanOption."
                           .format(variable_path))
-        errors += self.vocab._validate_helper(variable_path)
+        errors += self.vocab._validate_helper(variable_path + '.vocab')
         return errors
 
 
@@ -451,6 +464,38 @@ class DataLabelerOptions(BaseColumnOptions):
         BaseColumnOptions.__init__(self)
         self.data_labeler_dirpath = None
         self.max_sample_size = None
+        self.data_labeler_object = None
+
+    def __deepcopy__(self, memo):
+        """
+        Override deepcopy for data labeler object
+        Adapted from https://stackoverflow.com/questions/1500718/
+        how-to-override-the-copy-deepcopy-operations-for-a-python-object/40484215
+        :param memo: data object needed to copy
+        :return:
+        """
+        cls = self.__class__
+        result = cls.__new__(cls)
+        memo[id(self)] = result
+        for k, v in self.__dict__.items():
+            if k == 'data_labeler_object':
+                setattr(result, k, v)
+            else:
+                setattr(result, k, copy.deepcopy(v, memo))
+        return result
+
+    @property
+    def properties(self):
+        """
+        Returns a copy of the option properties.
+
+        :return: dictionary of the option's properties attr: value
+        :rtype: dict
+        """
+        props = {k: copy.deepcopy(v)
+                 for k,v in self.__dict__.items() if k != 'data_labeler_object'}
+        props['data_labeler_object'] = self.data_labeler_object
+        return props
 
     def _validate_helper(self, variable_path='DataLabelerOptions'):
         """
@@ -466,6 +511,14 @@ class DataLabelerOptions(BaseColumnOptions):
                 not isinstance(self.data_labeler_dirpath, str):
             errors.append("{}.data_labeler_dirpath must be a string."
                           .format(variable_path))
+        if self.data_labeler_object and \
+                not isinstance(self.data_labeler_object, BaseDataLabeler):
+            errors.append("{}.data_labeler_object must be a BaseDataLabeler "
+                          "object."
+                          .format(variable_path))
+        if self.data_labeler_object and self.data_labeler_dirpath:
+            warnings.warn("The data labeler passed in will be used,"
+                          " not through the directory of the default model")
         if self.max_sample_size and not isinstance(self.max_sample_size, int):
             errors.append("{}.max_sample_size must be a string."
                           .format(variable_path))
@@ -520,7 +573,21 @@ class StructuredOptions(BaseOption):
         :rtype: list(str)
         """
         errors = []
+
+        prop_check = dict([
+            ('int', IntOptions),
+            ('float', FloatOptions),
+            ('datetime', DateTimeOptions),
+            ('text', TextOptions),
+            ('order', OrderOptions),
+            ('category', CategoricalOptions),
+            ('data_labeler', DataLabelerOptions)
+        ])
+
         for column in self.properties:
+            if not isinstance(self.properties[column], prop_check[column]):
+                errors.append("{} must be a(n) {}.".format(
+                    column, prop_check[column].__name__))
             errors += self.properties[column]._validate_helper(
                 variable_path=(variable_path + '.' + column
                                if variable_path else column))
